"use client"

import { Flex, useDisclosure, useToast } from "@chakra-ui/react";
import { Button, FormControl, FormLabel, Text, useColorModeValue, Modal, ModalBody, ModalCloseButton, ModalContent, ModalFooter, ModalHeader, ModalOverlay } from "@chakra-ui/react";
import { InputWrapper } from "@/components/fields/Fields";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { useEffect, useMemo, useRef, useState } from "react";
import FormComponent from "@/components/form/Form";
import CustomCard from "@/components/card/Card";
import { useRouter } from "next/navigation";
import { userDeleteProfile } from "@/app/lib/user/action";
import { signOut } from "next-auth/react";
import { useGeneral } from "@/contexts/GeneralContext";


const formFields: FormObject[] = [
  {
    name: "contact",
    label: "Contact Details",
    type: "number",
    defaultValue: 0,
    required: true,
  },
  {
    name: "club_share",
    label: "Club Share",
    type: "number",
    defaultValue: 0,
    min: 0,
    max: 10,
    required: true,
  },
];

interface formValues {
  coins: string;
}

export default function DeleteProfile() {
  const { isClubOwner, isAdmin } = useGeneral();
  
  const toast = useToast();
  const router = useRouter();
  const { isOpen, onOpen, onClose } = useDisclosure();

  // page styles
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const brandStars = useColorModeValue("brand.500", "brand.400");


  const handleSubmit = async () => {
    const res = await userDeleteProfile();
    
    if (res.status == 200) {
      toast({
        title: "200",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      signOut();
    } else {
      toast({
        title: res.status,
        description: res.error,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };


  if (isClubOwner || isAdmin) {
    return null;
  }

  return (
    <CustomCard w="100%">
      <Flex align="center" w="100%">
        <Button fontSize="sm" onClick={onOpen} type="button" variant="alertBrand" fontWeight="500" h="50" mb="28px">
          Delete Profile
        </Button>
      </Flex>

      <Modal onClose={onClose} size="lg" isOpen={isOpen}>
        <ModalOverlay />
        <ModalContent bg={"navy.900"}>
          <ModalHeader display="flex" alignItems="center" gap="2">
            Account Deletion Warning!{" "}
          </ModalHeader>
          <ModalCloseButton />
          <ModalBody>
            <Flex justifyContent="space-between">
              <Text mb="36px" color={textColor} fontWeight="400" fontSize="md">
                Please be advised that deleting your account is irreversible. Once deleted, all associated data and settings will be permanently removed and cannot be recovered. Proceed with caution.{" "}
              </Text>
            </Flex>
          </ModalBody>
          <ModalFooter>
            <Button variant="alertBrand" onClick={() => handleSubmit()} type="button" mr={3}>
              Confirm
            </Button>
            <Button onClick={onClose}>Cancel</Button>
          </ModalFooter>
        </ModalContent>
      </Modal>
    </CustomCard>
  );
}
